@@ -1,13 +1,13 @@
 package App::GitGot::Command::list;
-BEGIN {
-  $App::GitGot::Command::list::VERSION = '1.01';
+{
+  $App::GitGot::Command::list::VERSION = '1.02';
 }
 BEGIN {
   $App::GitGot::Command::list::AUTHORITY = 'cpan:GENEHACK';
 }
 # ABSTRACT: list managed repositories
 
-use Moose;
+use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
 
@@ -49,7 +49,7 @@ App::GitGot::Command::list - list managed repositories
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
